@@ -26,6 +26,7 @@
   / ==ooooooooooooooo==.o.  ooo= //   ,`\--{)B     ,"
  /_==__==========__==_ooo__ooo=_/'   /___________,"
 """
+import re
 from argparse import ArgumentParser
 from typing import Optional
 
@@ -79,66 +80,43 @@ class Command(IOSCommand):
 
         class Application(FridaApplication):
 
-            def on_spawn_added(self, spawn):
-                environ.logger.debug(f"{spawn} added")
-                if spawn.identifier != bundle_id:
-                    try:
-                        self.device.resume(spawn.pid)
-                    except Exception as e:
-                        environ.logger.error(f"{e}")
-                else:
-                    self.load_script(spawn.pid, resume=True)
-
             def on_session_detached(self, session, reason, crash) -> None:
                 environ.logger.info(f"{session} detached, reason={reason}")
                 if reason in ("connection-terminated", "device-lost"):
                     self.stop()
-                elif len(self._sessions) == 0:
+                elif len(self.sessions) == 0:
                     if args.auto_start:
                         app.load_script(app.device.spawn(bundle_id), resume=True)
 
         with IOSFridaServer(device=device, local_port=utils.pick_unused_port()) as server:
 
-            app = Application(
-                server,
-                user_parameters=user_parameters,
-                user_scripts=user_scripts,
-                enable_spawn_gating=True
-            )
-
             # 如果没有填包名，则找到顶层应用
             if utils.is_empty(bundle_id):
-                target_app = app.device.get_frontmost_application()
+                target_app = server.get_frontmost_application()
                 if target_app is None:
                     environ.logger.error("Unknown frontmost application")
                     return
                 bundle_id = target_app.identifier
 
-            target_pids = set()
+            app = Application(
+                server,
+                target_identifiers=rf"^{re.escape(bundle_id)}$",
+                user_parameters=user_parameters,
+                user_scripts=user_scripts,
+                enable_spawn_gating=True
+            )
 
             if args.spawn:
                 # 打开进程后注入
                 app.load_script(app.device.spawn(bundle_id), resume=True)
 
-            # 匹配正在运行的进程
-            else:
-                # 匹配所有app
-                for target_app in app.device.enumerate_applications():
-                    if target_app.pid > 0 and target_app.identifier == bundle_id:
-                        target_pids.add(target_app.pid)
+            elif app.inject_all():
+                # 注入所有进程进程
+                pass
 
-                # 匹配所有进程
-                for target_process in app.device.enumerate_processes():
-                    if target_process.pid > 0 and target_process.name == bundle_id:
-                        target_pids.add(target_process.pid)
-
-                if len(target_pids) > 0:
-                    # 进程存在，直接注入
-                    for pid in target_pids:
-                        app.load_script(pid)
-                elif args.auto_start:
-                    # 进程不存在，打开进程后注入
-                    app.load_script(app.device.spawn(bundle_id), resume=True)
+            elif args.auto_start:
+                # 进程不存在，打开进程后注入
+                app.load_script(app.device.spawn(bundle_id), resume=True)
 
             app.run()
 
